determine_lims: Determine plot limits from simulated output

View source: R/kernel_api.R

determine_limsR Documentation

Determine plot limits from simulated output

Description

Internal helper used by landscape constructors and downstream packages.

Usage

determine_lims(output, var_names, lims)

Arguments

output

A matrix of simulation output, or a list containing one.

var_names

The target variable names.

lims

User-supplied limits, if any.

Value

A numeric vector of axis limits.


simlandr documentation built on June 22, 2026, 5:08 p.m.