| determine_lims | R Documentation |
Internal helper used by landscape constructors and downstream packages.
determine_lims(output, var_names, lims)
output |
A matrix of simulation output, or a list containing one. |
var_names |
The target variable names. |
lims |
User-supplied limits, if any. |
A numeric vector of axis limits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.